@@ -12,19 +12,15 @@
 #ifdef SUNOS
 #include <string.h>
 #endif
+#ifdef SCO
+#include <string.h>
+#endif
 
 // this is for OS/2 - RVI
 #ifdef __EMX__
 #include <float.h>
 #endif
 
-//#ifndef SUNOS
-//#ifndef HP_UX
-//#ifdef __LINUX__
-//#include <getopt.h>
-//#endif
-//#endif
-//#endif
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
 #include <X11/Xutil.h>
@@ -89,12 +85,13 @@ void open_setcustompalette(XColor *inpal)
 
 void do_setcustompalette(XColor *inpal)
 {
-//        char s[100];
         int i,n,me=0,flag[256],vid;
+	int depth;
 	long unsigned int plane_masks[3];
 	XColor pal[256];
-printf("Got to do_setcustompalette()\n");
+//printf("Got to do_setcustompalette()\n");
 	display.cmap=XDefaultColormap(display.dpy,display.screen);
+	depth=DefaultDepth(display.dpy, display.screen);
 	if (XAllocColorCells(display.dpy,display.cmap,0
 		,plane_masks,0,colour_table,256)==0)
 	{
@@ -104,9 +101,8 @@ printf("Got to do_setcustompalette()\n");
                 	,DefaultVisual(display.dpy,display.screen)
 		/*	,PseudoColor */
 			,AllocNone);
-//	XSetWindowColormap(display.dpy,display.win,display.cmap); // 1
 printf("map entries=%d\n",me);
-	        if (me==256) 
+	        if (me==256 && depth!=24) 
 		{
 			if (XAllocColorCells(display.dpy,display.cmap,0
                 		,plane_masks,0,colour_table,256)!=0)
@@ -131,7 +127,7 @@ printf("map entries=%d\n",me);
                 pal[n].green=inpal[n].green << 10;
                 pal[n].blue=inpal[n].blue << 10;
                 pal[n].flags= DoRed | DoGreen | DoBlue;
-		if (me==256)
+		if (me==256 && depth!=24)
 			pal[n].pixel=colour_table[n];
 		else
 		{
@@ -146,22 +142,12 @@ printf("map entries=%d\n",me);
 		}
                 flag[n]=1;
         }
-//        for (i=0;i<256;i++)
-//               if (flag[i]==0)
-//                {
-//                        printf("Colour %d not loaded\n",i);
-//                        do_error("Can't continue");
-//                }
-//	if (me==256)
-//	        XStoreColors(display.dpy,display.cmap,pal,256);
-//        XSetWindowColormap(display.dpy,display.win,display.cmap);
-	if (me==256)
+	if (me==256 && depth!=24)
 	{
 		XStoreColors(display.dpy,display.cmap,pal,256);
 		XFlush(display.dpy);
 	}
-//	else
-		XSetWindowColormap(display.dpy,display.win,display.cmap);
+	XSetWindowColormap(display.dpy,display.win,display.cmap);
 }
 
 void initfont()
@@ -185,10 +171,8 @@ void Fgl_setfontcolors(int bg,int fg)
 void parse_xargs(int argc, char **argv, char **geometry)
 {
 	int         option;
-//	extern int  optind;
 	extern char *optarg;
 
-//	int bits,i;
 #ifdef ALLOW_PIX_DOUBLING
 printf("Options include Pix doubling\n");
 	while ((option = getopt(argc,argv,"vbndg:wR:G:B:")) != EOF)
@@ -265,10 +249,8 @@ void Create_Window(char *geometry)
 	XSizeHints          sizehint;
 	XWMHints            wmhints;
 	int depth;
-//	long unsigned int plane_masks[3];
 	unsigned char       wname[256];     /* Window Name */
 	unsigned long vmask=CWEventMask | CWBackPixel | CWBackingStore;
-//	XVisualInfo vinfo;
 
 	depth=DefaultDepth(display.dpy, display.screen);
         xswa.event_mask = 0;
@@ -278,41 +260,13 @@ printf("DefaultVisual id=%d bp-rgb=%d map-entries=%d\n"
  ,(int)(*DefaultVisual(display.dpy,display.screen)).visualid
  ,(*DefaultVisual(display.dpy,display.screen)).bits_per_rgb
  ,(*DefaultVisual(display.dpy,display.screen)).map_entries);
-//	if (XMatchVisualInfo(display.dpy
-//		,display.screen,depth,
-//		TrueColor
-//		/* DirectColor */
-//		/* PseudoColor */
-//		,&vinfo))
-//	{
-//		vid=vinfo.visual;
-//		display.cmap=xswa.colormap=XCreateColormap(display.dpy
-//			,display.root,vid, AllocNone ); // 1
-//		printf("Got a TrueColor visual.\n");
-//               if (XAllocColorCells(display.dpy,display.cmap,0
-//                      ,plane_masks,0,colour_table,256)!=0)
-//		        printf("Allocated 256 cells\n");
-//		else
-//		{
-//			printf("... but couldn't allocate colours.\n");
-//			printf("Using default visual\n");
-//			vid=DefaultVisual(display.dpy, display.screen);
-//		}
-//		if (vid!=DefaultVisual(display.dpy, display.screen))
-//			vmask|=CWColormap;
-//	}
-//	else
-//	{
 		vid=DefaultVisual(display.dpy, display.screen);
 		display.cmap
 			=XDefaultColormap(display.dpy,display.screen);
 		printf("Using default visual\n");
-//	}
         display.win = XCreateWindow(display.dpy, display.root, 
             winX, winY, 
-            winW, winH, 0, 
-//            DefaultDepth(display.dpy, display.screen), 
-		depth,
+            winW, winH, 0, depth,
             InputOutput,  /* vid , */
           DefaultVisual(display.dpy, display.screen), 
 	/*	PseudoColor,  */
@@ -388,7 +342,6 @@ void Fgl_setpixel(int x,int y,int col)
 		if (x<xclip_x1 || x>xclip_x2 || y<xclip_y1 || y>xclip_y2)
 			return; 
 	col&=0xff;
-//printf("In setpixel\n");
 #ifdef ALLOW_PIX_DOUBLING
 	if (pix_double)
 	{
@@ -423,23 +376,6 @@ int Fgl_getpixel(int x,int y)
 void Fgl_hline(int x1,int y1,int x2,int col)
 {
         int x,i;
-//	if (clipping_flag)
-//	{
-//		if (x1<xclip_x1)
-//			x1=xclip_x1;
-//		else if (x1>xclip_x2)
-//			x1=xclip_x2;
-//		if (y1<xclip_y1)
-//			return;
-//		else if (y1>xclip_y2)
-//			return;
-//               if (x2<xclip_x1)
-//                        x2=xclip_x1;
-//                else if (x2>xclip_x2)
-//                        x2=xclip_x2;
-//	}
-
-//printf("In hline %d %d %d %d\n",x1,y1,x2,col);
 	col&=0xff;
         i=(y1+bordery)*(640+BORDERX);
         for (x=x1+borderx;x<=x2+borderx;x++)
@@ -460,27 +396,9 @@ void Fgl_line(int x1,int y1,int dummy,int y2,int col)
 // vertical lines only.
 {
         int y;
-//printf("In (v)line %d %d %d %d\n",x1,y1,y2,col);
-//        if (clipping_flag)
-//        {
-//                if (x1<xclip_x1)
-//                        x1=xclip_x1;
-//                else if (x1>xclip_x2)
-//                        x1=xclip_x2;
-//                if (y1<xclip_y1)
-//                        y1=xclip_y1;
-//                else if (y1>xclip_y2)
-//                        y1=xclip_y2;
-//                if (y2<xclip_y1)
-//                        y2=xclip_y1;
-//                else if (y2>xclip_y2)
-//                        y2=xclip_y2;
-//	}
-
 	col&=0xff;
         for (y=y1+bordery;y<=y2+bordery;y++)
                 *(pixmap+x1+borderx+(y*(640+BORDERX)))=col;
-//printf("In line - got set up pixmap\n");
 #ifdef ALLOW_PIX_DOUBLING
 	if (pix_double)
 		XFillRectangle(display.dpy,display.win
@@ -496,7 +414,6 @@ void Fgl_line(int x1,int y1,int dummy,int y2,int col)
 void Fgl_write(int x,int y, char *s)
 {
 	int i;
-//printf("writing <%s>\n",s);
 	for (i=0;i<(int)(strlen(s));i++)
 		my_x_putchar(x+i*8,y,s[i]);
 }
@@ -504,7 +421,6 @@ void Fgl_write(int x,int y, char *s)
 void open_write(int x,int y, char *s)
 {
         int i;
-//printf("writing <%s>\n",s);
         for (i=0;i<(int)(strlen(s));i++)
                 open_x_putchar(x+i*8,y,s[i]);
 }
@@ -512,7 +428,6 @@ void open_write(int x,int y, char *s)
 void my_x_putchar(int xx,int yy,int c)
 {
 	int x,y,b;
-//printf(" %c",c);
 	for (y=0;y<8;y++)
 	{
 		b=myfont[c*8+y];
@@ -530,7 +445,6 @@ void my_x_putchar(int xx,int yy,int c)
 void open_x_putchar(int xx,int yy,int c)
 {                                          
         int x,y,b;                         
-//printf(" %c",c);
         for (y=0;y<open_font_height;y++)                  
         {                                  
                 b=open_font[c*open_font_height+y];           
@@ -560,18 +474,10 @@ void Fgl_fillbox(int x1,int y1,int w,int h,int col)
 			h=xclip_y2-y1;
 	}
 	col&=0xff;
-//printf("In fillbox %d %d %d %d %d\n",x1,y1,w,h,col);
-//	if ((y1+h)>480)
-//	{
-//		printf("Bad y1+h in fillbox val=%d\n",y1+h);
-//		h=y1-480;
-//	}
 	for (y=y1+bordery;y<y1+h+bordery;y++)
 	{
 		for (x=x1+borderx;x<x1+w+borderx;x++)
 			*(pixmap+y*(640+BORDERX)+x)=col;
-//		XDrawLine(display.dpy,display.win,display.pixcolour_gc[col]
-//		,x1+borderx,y,x1+w-1+borderx,y);
 	}
 #ifdef ALLOW_PIX_DOUBLING
 	if (pix_double)
@@ -581,8 +487,6 @@ void Fgl_fillbox(int x1,int y1,int w,int h,int col)
 #endif
 	XFillRectangle(display.dpy,display.win
 		,display.pixcolour_gc[col],x1+borderx,y1+bordery,w,h);
-
-//printf("Done\n");
 }
 
 void Fgl_putbox(int x1,int y1,int w,int h,void *buf)
@@ -590,11 +494,9 @@ void Fgl_putbox(int x1,int y1,int w,int h,void *buf)
 	unsigned char *b;
 	b=(unsigned char *)buf;
 	int x,y;
-//printf("In Fgl_putbox(%d %d %d %d %p\n",x1,y1,w,h,buf);
 	for (y=y1;y<y1+h;y++)
 		for (x=x1;x<x1+w;x++)
 		{
-//printf(" %d ",*b);
 			Fgl_setpixel(x,y,*(b++));
 		}
 }
@@ -611,7 +513,6 @@ void Fgl_getbox(int x1,int y1,int w,int h,void *buf)
 
 void HandleEvent(XEvent *event)
 {
-//printf("XEvent - type=%d\n",event->type);
 	switch (event->type)
 	{
 		case (KeyPress):
@@ -621,12 +522,7 @@ void HandleEvent(XEvent *event)
                 	KeySym ks;
                 	XComposeStatus status;
 			XLookupString(key_event,buf,128,&ks,&status);
-//			if (buf[0]=='q' || buf[0]=='Q')
-//				stopflag=TRUE;
-//			else if (buf[0]=='r' || buf[0]=='R')
-//				refresh_screen(0,0,640,480);
 			x_key_value=buf[0];
-//printf("Key=%d\n",x_key_value);
 			if (x_key_value==XK_Return)
 				x_key_value=0xd;
 			else if (x_key_value==XK_BackSpace
@@ -642,15 +538,11 @@ void HandleEvent(XEvent *event)
 				cs_mouse_shifted=1;
 			else
 				cs_mouse_shifted=0;
-//printf("Button %d pressed\n",mouse_button);
-//printf("Button state = %d\n",cs_mouse_shifted);
-//			do_buttons(0,0);
 			cs_mouse_handler(mouse_button,0,0);
 		} break;
 
 		case (ButtonRelease):
 		{
-//printf("Button released\n");
 			mouse_button=0;
 			cs_mouse_handler(mouse_button,0,0);
 		} break;
@@ -659,33 +551,41 @@ void HandleEvent(XEvent *event)
 		{
 			if (suppress_next_expose)
 			{
-// printf("Expose event supressed\n");
 				suppress_next_expose=0;
 				break;
 			}
 			XExposeEvent *ev = (XExposeEvent *) event;
-printf("Expose event\n");
-// printf("Expose event %d %d %d %d\n",ev->x,ev->y,ev->x+ev->width
-// ,ev->y+ev->height);
+//printf("Expose event\n");
 			refresh_screen(ev->x,ev->y
 				,ev->x+ev->width,ev->y+ev->height);
 		} break;
 
-//		default: printf("Unknown event %d\n",event->type);
 	}
 }
 
 void refresh_screen(int x1,int y1,int x2,int y2)  // bounds of refresh area
 {
 	int x,y;
-//printf("In refresh %d %d %d %d\n",x1,y1,x2,y2);
-	for (y=y1;y<y2;y++)
+#ifdef ALLOW_PIX_DOUBLING
+        if (pix_double)
+        {
+		for (y=y1;y<y2;y++)
 		for (x=x1;x<x2;x++)
+                        XFillRectangle(display.dpy,display.win
+				,display.pixcolour_gc[*(pixmap+x+y
+				*(640+BORDERX))&0xff],x*2,y*2,2,2);
+        }
+        else
+        {
+#endif
+	for (y=y1;y<y2;y++)
+	for (x=x1;x<x2;x++)
                 XDrawPoint(display.dpy,display.win
                         ,display.pixcolour_gc[*(pixmap
 				+x+y*(640+BORDERX))&0xff],x,y);
-//			Fgl_setpixel(x,y,*(pixmap+x+y*(640+BORDERX)));
-//printf("Got past draws\n");
+#ifdef ALLOW_PIX_DOUBLING
+	}
+#endif
 }
 
 void Fgl_enableclipping(void)
@@ -710,9 +610,7 @@ void do_call_event(int wait)
 {
         int dummy_int,x,y;
         Window dummy_win;
-//printf("In call event\n");
 	XEvent xev;
-//	x_key_value=0;
         if (XPending(display.dpy) )  // || wait!=0)
         {
                 XNextEvent(display.dpy, &xev);
@@ -1049,11 +947,6 @@ void init_pixmaps()
         init_icon_pixmap(CST_POWERS_SOLAR);
         init_icon_pixmap(CST_UNIVERSITY);
         init_icon_pixmap(CST_EX_PORT);
-
-//        init_icon_pixmap();
-//        init_icon_pixmap();
-//        init_icon_pixmap();
-
 }
 
 void init_icon_pixmap(int type)
@@ -1072,7 +965,6 @@ void init_icon_pixmap(int type)
 		,main_types[type].size*16,main_types[type].size*16
 		,DefaultDepth(display.dpy, display.screen));
 
-//printf("icon_pixmap[%d]=%x",type,icon_pixmap[type]);
 	g=(unsigned char *)main_types[type].graphic;
 #ifdef ALLOW_PIX_DOUBLING
 	if (pix_double)
@@ -1093,42 +985,17 @@ void init_icon_pixmap(int type)
 #ifdef ALLOW_PIX_DOUBLING
 	}
 #endif
-//printf(" - done.\n");
 }
 
-//void update_pixmap(int x1,int y1,int sizex,int sizey,int dx,int dy
-//	,int real_size,char *g)
-//{
-//	int x,y,*i,*j;
-//#ifdef CATCH_U_P_SIZE_FAULT
-//	if ((sizex % sizeof(int)) !=0)
-//		printf("Bad size for update_pixmap - x=%d \n"
-//			,sizex);
-//#endif
-//printf("x1=%d y1=%d sizex=%d sizey=%d dx=%d dy=%d\n",x1,y1,sizex
-//,sizey,dx,dy);
-//	for (y=0;y<sizey;y++)
-//	{
-//		i=(int *)(pixmap+((dy+y+bordery)*(640+BORDERX)+dx+borderx));
-//		j=(int *)(g+((y1+y)*real_size*16+x1));
-//printf("%p %p -> %p %p size=%d\n",pixmap,g,i,j,real_size);
-//		for (x=0;x<(int)(sizex/sizeof(int));x++)
-//			*(i++)=*(j++);
-//	}
-//}
-
 void update_pixmap(int x1,int y1,int sizex,int sizey,int dx,int dy
         ,int real_size,char *g)
 {
 	char *i,*j;
         int x,y;
-//printf("x1=%d y1=%d sizex=%d sizey=%d dx=%d dy=%d\n",x1,y1,sizex
-//,sizey,dx,dy);
         for (y=0;y<sizey;y++)
         {
                 i=(pixmap+((dy+y+bordery)*(640+BORDERX)+dx+borderx));
                 j=(g+((y1+y)*real_size*16+x1));
-//printf("%p %p -> %p %p size=%d\n",pixmap,g,i,j,real_size);
                 for (x=0;x<sizex;x++)
                         *(i++)=*(j++);
         }
