@@ -5,6 +5,9 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <strings.h>
+#ifdef SCO
+#include <string.h>
+#endif
 
 #ifdef LC_X11
 #include <X11/Xlib.h>
@@ -31,7 +34,6 @@
 #include <fcntl.h>
 #include <unistd.h>
 #include <sys/time.h>
-//#include <sys/times.h>
 #include <ctype.h>
 #include "lctypes.h"
 #include "lin-city.h"
@@ -55,6 +57,7 @@ main(int argc,char *argv[])
 	int x,y;
 #else
 	int q;
+	vga_init();
 #endif
 	main_screen_originx=1;
 	main_screen_originy=1;
@@ -84,23 +87,13 @@ main(int argc,char *argv[])
 	borderx=BORDERX;
 	bordery=BORDERY;
         parse_xargs(argc,argv,&geometry);
-// printf("Got past parse args\n");
         Create_Window(geometry);
-/// printf("Got past create_window, proper\n");
-///        XSync(display.dpy,FALSE);
 
-//        while (XPending(display.dpy)==0);
-//        XNextEvent(display.dpy, &xev);
-//        HandleEvent(&xev);
-
-///        printf("Got past create window\n");
 	pirate_cursor=XCreateFontCursor(display.dpy,XC_pirate);
 #else
 	parse_args(argc,argv);
-	vga_init();
 	q=vga_setmode(G640x480x256);
 	gl_setcontextvga(G640x480x256);
-//	printf("vga_setmode returned %d\n",q);
 #endif
 
 	load_start_image();
@@ -115,7 +108,6 @@ main(int argc,char *argv[])
         } while (xev.type!=UnmapNotify);
 
 	Create_Window(geometry);
-//        XSync(display.dpy,FALSE);
 	setcustompalette();
 	suppress_next_expose=1;
 	do
@@ -157,7 +149,6 @@ main(int argc,char *argv[])
 	mouse_setup();
 #endif
 	init_types();
-//	printf("Got past init_types\n");
 	prog_box("",95);
 	clear_data();
 	prog_box("",100);
@@ -166,12 +157,9 @@ main(int argc,char *argv[])
 	init_pixmaps();
 	prog_box("",100);
 #endif
-//	prog_box("",100);
-//	printf("Starting screen_setup\n");
 	draw_normal_mouse(1,1);
 	screen_setup();
 	draw_sustainable_window();
-//	printf("Done - screen_setup\n");
 	coal_reserve_setup();
 	setup_river();
 	ore_reserve_setup();
@@ -196,7 +184,6 @@ void test(void)
 	if (gettimeofday(&lc_timeval,0)!=0)
 		do_error("Can't get timeofday");
 	real_start_time=lc_timeval.tv_sec;
-//	printf("Calling draw_mini_screen\n");
 	draw_mini_screen();
 	if (no_init_help==0)
 	{
@@ -204,7 +191,6 @@ void test(void)
 		help_flag=1;
 		activate_help("opening.hlp");
 	}
-//	printf("Starting main loop\n");
 	selected_type=CST_TRACK_LR;
 	selected_type_cost=GROUP_TRACK_COST;
 	old_selected_button=sbut[7];
@@ -217,7 +203,6 @@ void test(void)
 #endif
 	do
 	{
-//printf("Help flag=%d\n",help_flag);
 		if (reset_mouse_flag!=0)
 		{
 			cs_mouse_handler(0,0,0);
@@ -231,7 +216,6 @@ void test(void)
 #else
 		q=vga_getkey();
 #endif
-//		debug_writeval(cs_mouse_button);
 		if (q==' ' || q==10 || q==13 || q==127)
 		{
 #ifdef LC_X11
@@ -241,7 +225,6 @@ void test(void)
 				cs_mouse_handler(MOUSE_RIGHTBUTTON,0,0);
 			else
 				cs_mouse_handler(MOUSE_LEFTBUTTON,0,0);
-//			cs_mouse_button=0;
 			cs_mouse_handler(0,0,0); // ouch!
 //  No, the following line is not really there - you're seeing things :)
 //  This is a good time to go to bed.
@@ -284,7 +267,7 @@ void test(void)
 #endif
 this_is_not_really_here:  // :)
 
-// ooch!
+// ouch!
 			if ((real_time<next_time_step 
 		|| pause_flag || mt_flag)
 		&& market_cb_flag==0 && help_flag==0 && port_cb_flag==0
@@ -294,8 +277,6 @@ this_is_not_really_here:  // :)
 					&& q!='s') || mt_flag)
 				{
 					lc_usleep(1);
-//printf(".");
-//fflush(stdout);
 					continue;
 				}
 				else
@@ -355,7 +336,6 @@ this_is_not_really_here:  // :)
 				>(GROUP_HEALTH_TECH*MAX_TECH_LEVEL/1000))
 			{
 				update_shanty();
-//				debug_writeval(numof_shanties);
 			}
 			if (mappoint_stats_flag 
 				&& real_time>mappoint_stats_time)
@@ -482,7 +462,6 @@ this_is_not_really_here:  // :)
 				real_quit_flag=1;
 			else
 				quit_flag=0;
-// printf("Help flag %d   Quit flag %d\n",help_flag,quit_flag);
 		}
 		if (help_flag!=0)
 			lc_usleep(1);
@@ -515,7 +494,6 @@ void clear_data(void)
 void do_save_city()
 {
         char s[200],c;
-//        int i;
         hide_mouse();
         Fgl_fillbox(MAIN_WIN_X,MAIN_WIN_Y,MAIN_WIN_W,MAIN_WIN_H
                         ,SAVE_BG_COLOUR);
@@ -527,7 +505,6 @@ void do_save_city()
 		,"Press space to cancel.");
         draw_save_dir(SAVE_BG_COLOUR);
 #ifdef LC_X11
-//        db_flag=1;
         redraw_mouse();
 	db_flag=1;
         cs_mouse_handler(0,-1,0);
@@ -538,9 +515,6 @@ void do_save_city()
                 c=x_key_value;
 	} while (c==0);
 	x_key_value=0;
-//	db_flag=0;
-//	cs_mouse_handler(0,-1,0);
-//	cs_mouse_handler(0,1,0);
 #else
         c=getchar();
 	redraw_mouse();
@@ -576,6 +550,8 @@ void do_save_city()
 void remove_scene(char *cname)
 {
 	char s[200];
+	if (strlen(cname) < 2)   //  Thanks to
+		return;          //  Chris J. Kiick
         strcpy(s,getenv("HOME"));
         strcat(s,"/");
         strcat(s,LC_SAVE_DIR);
@@ -586,20 +562,22 @@ void remove_scene(char *cname)
 
 void save_city(char *cname)
 {
-	char s[200],s2[200];
+	char s[200],s2[200],s3[200];
 	int x,y,z,q,n;
 	FILE *ofile;
         strcpy(s,getenv("HOME"));
         strcat(s,"/");
         strcat(s,LC_SAVE_DIR);
-        strcat(s,"/");
+	strcat(s,"/");
+	strcpy(s2,s);
+        strcat(s2,"tmp-save");
         strcat(s,cname);
 //	strcpy(s2,"gzip -c -9 > ");
-	strcpy(s2,"gzip -c > ");
-	strcat(s2,s);
-	if ((ofile=popen(s2,"w"))==NULL)
+//	strcpy(s2,"gzip -c > ");
+//	strcat(s2,s);
+	if ((ofile=fopen(s2,"w"))==NULL)
 	{
-		printf("Save pipe <%s> - ",s2);
+		printf("Save file <%s> - ",s2);
 		do_error("Can't open it!");
 	}
 	fprintf(ofile,"%d\n",(int)VERSION);
@@ -744,14 +722,26 @@ void save_city(char *cname)
 	fprintf(ofile,"dummy\n");  // 8
 	fprintf(ofile,"dummy\n");  // 9
 	fprintf(ofile,"dummy\n");  // 10
-	pclose(ofile);
+	fclose(ofile);
+	strcpy(s3,"gzip -f ");
+	strcat(s3,s2);
+printf("(%s)\n",s3);
+	if (system(s3)!=0)
+		do_error("gzip failed while in save_city");
+	strcat(s2,".gz");
+	strcpy(s3,"mv ");
+	strcat(s3,s2);
+	strcat(s3," ");
+	strcat(s3,s);
+printf("(%s)\n",s3);
+	if (system(s3)!=0)
+		do_error("mv failed while in save_city");
 	prog_box("",100);
 }
 
 void do_load_city(void)
 {
 	char c;
-//	int i;
 	hide_mouse();
 	Fgl_fillbox(MAIN_WIN_X,MAIN_WIN_Y,MAIN_WIN_W,MAIN_WIN_H
 			,LOAD_BG_COLOUR);
@@ -783,7 +773,6 @@ void do_load_city(void)
 	x_key_value=0;
 #else
 	c=getchar();
-//	redraw_mouse();
 #endif
 	if (c>'0' && c<='9')
 		if (strlen(save_names[c-'0'])<1)
@@ -800,8 +789,6 @@ void do_load_city(void)
 		}
     } while ((c<='0' || c>'9') && c!=' ');
 	redraw_mouse();
-//	db_flag=1;
-//	cs_mouse_handler(0,-1,0);
 	if (c>'0' && c<='9')
 	{
 		if (yn_dial_box("Loading Scene"
@@ -828,41 +815,68 @@ void do_load_city(void)
 
 void load_op_city(char *s)
 {
+	char s1[256],s2[256];
+	strcpy(s1,"cp ");
+        strcat(s1,LIBDIR);
+        strcat(s1,"/opening/");
+	strcat(s1,s);
+	strcat(s1," ");
+        strcpy(s2,getenv("HOME"));
+        strcat(s2,"/");
+        strcat(s2,LC_SAVE_DIR);
+        strcat(s2,"/");
+	strcat(s2,s);
+	strcat(s1,s2);
+	if (system(s1)!=0)
+		do_error("Can't copy requested file to ~/.Lincity/...");
 	load_city(s);
+	remove(s2);
 	strcpy(given_scene,s);
         db_flag=0;
         cs_mouse_handler(0,-1,0);
         cs_mouse_handler(0,1,0);
-//        hide_mouse();
         Fgl_setfontcolors(TEXT_BG_COLOUR,TEXT_FG_COLOUR);
         refresh_main_screen();
         suppress_ok_buttons=1;
         update_select_buttons();
         suppress_ok_buttons=0;
-//        redraw_mouse();
 }
 
 void load_city(char *cname)
 {
-	char s[200],s2[200];
+	char s[200],s2[200],s3[100];
         int x,y,z,q,n,v,i;
         FILE *ofile;
-	if (cname[1]=='_')
-	{
+//	if (cname[1]=='_')
+//	{
         	strcpy(s,getenv("HOME"));
         	strcat(s,"/");
         	strcat(s,LC_SAVE_DIR);
 		strcat(s,"/");
-	}
-	else
-	{
-		strcpy(s,LIBDIR);
-		strcat(s,"/opening/");
-	}
+//	}
+//	else
+//	{
+//		strcpy(s,LIBDIR);
+//		strcat(s,"/opening/");
+//	}
+	strcpy(s2,s);
+	strcat(s2,"tmp-load");
 	strcat(s,cname);
-	strcpy(s2,"gzip -d -c ");
-	strcat(s2,s);
-        if ((ofile=popen(s2,"r"))==NULL)
+
+	strcpy(s3,"cp ");
+	strcat(s3,s);
+	strcat(s3," ");
+	strcat(s3,s2);
+	strcat(s3,".gz");
+	if (system(s3)!=0)
+		do_error("Can't copy selected file in load_city");
+
+	strcpy(s3,"gzip -d ");
+	strcat(s3,s2);
+	strcat(s3,".gz");
+	if (system(s3)!=0)
+		do_error("Can't uncompress (gzip) file in load city");
+        if ((ofile=fopen(s2,"r"))==NULL)
         {
                 printf("Load pipe <%s> - ",s2);
                 do_error("Can't open it!");
@@ -871,15 +885,13 @@ void load_city(char *cname)
 	if (v<MIN_LOAD_VERSION)
 	{
 		ok_dial_box("too-old.mes",BAD,0L);
-		pclose(ofile);
+		fclose(ofile);
 		return;
 	}
-//		do_error("Sorry wrong version of load file");
 	unprint_cheat();
         q=sizeof(struct MAPPOINT);
 	if (q!=40)
 	{
-//		char sq[100];
 		sprintf(s," %d %d ",sizeof(int),sizeof(unsigned short));
 		ok_dial_box("wrong-mpsize.mes",BAD,s);
 	}
@@ -890,11 +902,9 @@ void load_city(char *cname)
 	{
                 for (y=0;y<WORLD_SIDE_LEN;y++)
 		{
-//printf("x=%d y=%d  ",x,y);
                         for (z=0;z<q;z++)
                         {
                                 fscanf(ofile,"%d",&n);
-//printf("n=%d ",n);
 				*(((unsigned char *)&mappoint[x][y])+z)=n;
                         }
 			fscanf(ofile,"%d",&n);
@@ -902,15 +912,6 @@ void load_city(char *cname)
 			fscanf(ofile,"%d",&n);
 			mappointtype[x][y]=(unsigned short)n;
 
-//if (mappointtype[x][y]==CST_USED)
-//{
-//	printf("px=%d py=%d\n",mappoint[x][y].int_1,mappoint[x][y].int_2);
-//	if (mappoint[x][y].int_1<0 || mappoint[x][y].int_1>255
-//		|| mappoint[x][y].int_2<0 || mappoint[x][y].int_2>255)
-//		exit(1);
-//}
-//else
-//	printf(" Type=%d\n",mappointtype[x][y]);
 		if (((93*x)/WORLD_SIDE_LEN)%3==0)
 			prog_box("",(93*x)/WORLD_SIDE_LEN);
 		}
@@ -953,6 +954,8 @@ void load_city(char *cname)
 	fscanf(ofile,"%d",&import_cost);
 	fscanf(ofile,"%d",&import_cost_rate);
 	fscanf(ofile,"%d",&tech_level);
+	if (tech_level>MODERN_WINDMILL_TECH)
+		modern_windmill_flag=1;
 	fscanf(ofile,"%d",&tpopulation);
 	fscanf(ofile,"%d",&tstarving_population);
 	fscanf(ofile,"%d",&tunemployed_population);
@@ -1057,7 +1060,8 @@ pbar_money_olddiff=0;
                 =sust_old_money_count=sust_old_population_count
                 =sust_old_tech_count=sust_fire_count
                 =sust_old_money=sust_old_population=sust_old_tech=0;
-	pclose(ofile);
+	fclose(ofile);
+	remove(s2);
 	numof_shanties=count_groups(GROUP_SHANTY);
 	numof_communes=count_groups(GROUP_COMMUNE);
 	prog_box("",100);
@@ -1078,7 +1082,12 @@ pbar_money_olddiff=0;
 	else
 	university_intake_rate=50;
 
+        selected_type=CST_TRACK_LR;
+        selected_type_cost=GROUP_TRACK_COST;
+        old_selected_button=sbut[7];
+        highlight_select_button(sbut[7]);  // 7 is track.  Watch out though!
 
+	print_total_money();
 	reset_animation_times();
 }
 
@@ -1292,12 +1301,8 @@ void draw_save_dir(int bg_colour)
 	strcat(s,LC_SAVE_DIR);
 	if ((dp=opendir(s))==NULL)
 	{
-//		mkdir(s,0755);
-//		if ((dp=opendir(s))==NULL)
-//		{
 			printf("Couldn't find the save directory %s\n",s);
 			return;
-//		}
 	}
 	for (i=1;i<10;i++)
 	{
@@ -1328,7 +1333,6 @@ void draw_save_dir(int bg_colour)
 			Fgl_setfontcolors(bg_colour,red(28));
 		else
 			Fgl_setfontcolors(bg_colour,green(28));
-//printf("%s\n",s2);
 		Fgl_write(MAIN_WIN_X+24,MAIN_WIN_Y+10*(10+i),s2);
 		rewinddir(dp);
 	}
@@ -1488,7 +1492,6 @@ void load_start_image(void)
         pal[SI_YELLOW].blue=0;
         pal[SI_YELLOW].flags= DoRed | DoGreen | DoBlue;
 	open_setcustompalette(pal);
-//	XSync(display.dpy,FALSE);
         suppress_next_expose=1;
         do
         {
@@ -1521,7 +1524,6 @@ void load_start_image(void)
 			if (l==SI_YELLOW)
 				l=SI_YELLOW-4;
                         Fgl_setpixel(x,y,l);
-		//	printf("Set the pixel\n");
                 }
         fclose(fp);
 	start_image_text();
@@ -1738,16 +1740,6 @@ void time_for_year(void)
 void debug_stuff(void)
 {
 	int i;
-//	for (i=0;i<10;i++)
-//	{
-//		printf("Buf1[%d]=%d\n",i,buf1[i]);
-//		buf1[i]=1;
-//	}
-//	for (i=0;i<10;i++)
-//	{
-//		printf("Buf2[%d]=%d\n",i,buf2[i]);
-//		buf2[i]=1;
-//	}
 	for (i=0;i<NUMOF_GROUPS;i++)
 		printf("FC[%d]=%d\n",i,fire_chance[i]);
 
@@ -1846,7 +1838,6 @@ void lincityrc(void)
 			exit(1);
 		}
 		fprintf(rc,"mouse=%d\n",i-'0');
-//		fprintf(rc,"lc_save_dir=%s\n",lc_save_dir);
 		fclose(rc);
 #ifndef __EMX__
 		chown(s,getuid(),getgid());
@@ -1862,8 +1853,6 @@ void lincityrc(void)
 		fgets(s,99,rc);
 		if (sscanf(s,"mouse=%d",&i)!=0)
 			lc_mouse_type=i;
-//		if (sscanf(s1,"lc_save_dir=%s",s)!=0)
-//			strcpy(lc_save_dir,s1);
 	}
 	fclose(rc);
 }
@@ -1952,7 +1941,6 @@ void count_all_groups(void)
 int compile_results(void)
 {
 	char s[256];
-//	int l=0;
 	FILE *outf;
         strcpy(s,getenv("HOME"));
         strcat(s,"/");
@@ -2037,7 +2025,6 @@ void print_results(void)
         strcat(s,LC_SAVE_DIR);
         strcat(s,"/");
         strcat(s,RESULTS_FILENAME);
-//	printf("\n\n   LinCity   Results\n\n");
 	printf("\n");
 	system(s);
 	printf("\n");
@@ -2307,64 +2294,11 @@ void dump_tcore(void)
 	fprintf(ofile,"ore_used=%d\n",ore_used);
 	fprintf(ofile,"diff_old_population=%d\n",diff_old_population);
 	prog_box("",96);
-//	for (x=0;x<MAPPOINT_STATS_W;x++)
-//	{
-//		fprintf(ofile,"%d\n",monthgraph_pop[x]);
-//		fprintf(ofile,"%d\n",monthgraph_starve[x]);
-//		fprintf(ofile,"%d\n",monthgraph_nojobs[x]);
-//		fprintf(ofile,"%d\n",monthgraph_ppool[x]);
-//		fprintf(ofile,"%d\n",diffgraph_power[x]);
-//		fprintf(ofile,"%d\n",diffgraph_coal[x]);
-//		fprintf(ofile,"%d\n",diffgraph_goods[x]);
-//		fprintf(ofile,"%d\n",diffgraph_ore[x]);
-//		fprintf(ofile,"%d\n",diffgraph_population[x]);
-//	}
 	prog_box("",98);
 	fprintf(ofile,"rockets_launched=%d\n",rockets_launched);
 	fprintf(ofile,"rockets_launched_success=%d\n",rockets_launched_success);
 	fprintf(ofile,"coal_survey_done=%d\n",coal_survey_done);
-//	for (x=0;x<12;x++)
-//	{
-//		fprintf(ofile,"%d\n",pbar_pops[x]);
-//		fprintf(ofile,"%d\n",pbar_techs[x]);
-//		fprintf(ofile,"%d\n",pbar_foods[x]);
-//		fprintf(ofile,"%d\n",pbar_jobs[x]);
-//		fprintf(ofile,"%d\n",pbar_money[x]);
-//		fprintf(ofile,"%d\n",pbar_coal[x]);
-//		fprintf(ofile,"%d\n",pbar_goods[x]);
-//		fprintf(ofile,"%d\n",pbar_ore[x]);
-//		fprintf(ofile,"%d\n",pbar_steel[x]);
-//	}
 	prog_box("",99);
-//	fprintf(ofile,"%d\n",pbar_pop_oldtot);
-//	fprintf(ofile,"%d\n",pbar_pop_olddiff);
-//	fprintf(ofile,"%d\n",pbar_tech_oldtot);
-//	fprintf(ofile,"%d\n",pbar_tech_olddiff);
-//	fprintf(ofile,"%d\n",pbar_food_oldtot);
-//	fprintf(ofile,"%d\n",pbar_food_olddiff);
-//       fprintf(ofile,"%d\n",pbar_jobs_oldtot);
-//        fprintf(ofile,"%d\n",pbar_jobs_olddiff);
-//        fprintf(ofile,"%d\n",pbar_money_oldtot);
-//        fprintf(ofile,"%d\n",pbar_money_olddiff);
-//        fprintf(ofile,"%d\n",pbar_coal_oldtot);
-//        fprintf(ofile,"%d\n",pbar_coal_olddiff);
-//        fprintf(ofile,"%d\n",pbar_goods_oldtot);
-//        fprintf(ofile,"%d\n",pbar_goods_olddiff);
-//        fprintf(ofile,"%d\n",pbar_ore_oldtot);
-//        fprintf(ofile,"%d\n",pbar_ore_olddiff);
-//        fprintf(ofile,"%d\n",pbar_steel_oldtot);
-//        fprintf(ofile,"%d\n",pbar_steel_olddiff);
-
-//	fprintf(ofile,"%d\n",cheat_flag);
-//        fprintf(ofile,"%d\n",total_pollution_deaths);
-//        fprintf(ofile,"%f\n",pollution_deaths_history);
-//        fprintf(ofile,"%d\n",total_starve_deaths);
-//        fprintf(ofile,"%f\n",starve_deaths_history);
-//        fprintf(ofile,"%d\n",total_unemployed_years);
-//        fprintf(ofile,"%f\n",unemployed_history);
-//	fprintf(ofile,"%d\n",max_pop_ever);
-//	fprintf(ofile,"%d\n",total_evacuated);
-//	fprintf(ofile,"%d\n",total_births);
 
 	fclose(ofile);
 	prog_box("",100);
@@ -2403,11 +2337,8 @@ void sanity_check(void)
 void parse_args(int argc, char **argv)
 {
         int         option;
-//        extern int  optind;
         extern char *optarg;
 
-//        int bits,i;
-
         while ((option = getopt(argc,argv,"wR:G:B:")) != EOF)
         {
                 switch (option)
@@ -2461,7 +2392,6 @@ void sustainability_test(void)
 
 // population must be withing 2% of when it started.
 	i=(housed_population+people_pool)-sust_old_population;
-// printf("tpopulation=%d i=%d sop=%d\n",tpopulation,i,sust_old_population);
 	if ( abs(i) > (sust_old_population/40)  // 2.5% 
 		|| (housed_population+people_pool)<SUST_MIN_POPULATION)
 	{
@@ -2523,9 +2453,6 @@ int sust_fire_cover(void)
 			if ((mappoint[x][y].flags&FLAG_FIRE_COVER)==0)
 				return(0);
 	}
-//printf("We have total fire cover in year %d\n"
-//,total_time/NUMOF_DAYS_IN_YEAR);
-
 	return(1);
 }
 
